@@ -2,6 +2,7 @@ from itsimodels.core.base_models import (
     BaseModel,
     ChildModel
 )
+from itsimodels.core.compat import string_types
 from itsimodels.core.fields import (
     BoolField,
     DictField,
@@ -32,6 +33,8 @@ class DashboardDrilldown(ChildModel):
 
     id = StringField(required=True)
 
+    dashboard_type = StringField(required=True)
+
     base_url = StringField(default='')
 
     is_splunk_dashboard = BoolField(default=False)
@@ -46,9 +49,9 @@ class VitalMetric(ChildModel):
 
     is_key = BoolField(default=False)
 
-    matching_entity_fields = ListField(str)
+    matching_entity_fields = ListField(string_types)
 
-    split_by_fields = ListField(str)
+    split_by_fields = ListField(string_types)
 
     unit = StringField(default='')
 
